"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/* eslint-disable no-process-exit */
var userConfig_1 = __importDefault(require("./userConfig"));
var cliConfig_1 = __importDefault(require("./cliConfig"));
var utils_1 = require("./utils");
var userPackageScripts_1 = __importDefault(require("./userPackageScripts"));
var loadRules_1 = require("./loadRules");
var execute_1 = __importDefault(require("./execute"));
var consoleReporter_1 = require("./consoleReporter");
var constants_1 = require("./constants");
/* istanbul ignore next */
var processExit = function (code) {
    if (typeof process.env.JEST_WORKER_ID === "undefined") {
        // eslint-disable-next-line node/no-process-exit
        process.exit(code);
    }
};
exports.default = (function (argv) {
    var _a;
    try {
        /**
         * config assembly
         */
        var userConfig = userConfig_1.default();
        var cliConfig = cliConfig_1.default(argv);
        var config = __assign(__assign(__assign(__assign({}, constants_1.DEFAULT_CONFIG), { json: false }), userConfig), cliConfig);
        // output the config (--config) but only if we don't want JSON output on the CLI
        if (!config.json && config.config) {
            var json = JSON.stringify(config, null, 2);
            // eslint-disable-next-line no-console
            console.log("\n\n" + json + "\n\n");
        }
        /**
         * package.json
         */
        var _b = userPackageScripts_1.default(utils_1.makePackageFilePath((_a = config.packageFile) !== null && _a !== void 0 ? _a : process.cwd())), writePackageScripts = _b.writePackageScripts, readPackageScripts = _b.readPackageScripts;
        var scripts = readPackageScripts(config.ignoreScripts);
        /**
         * rule loading
         */
        var rules = loadRules_1.loadRulesFromRuleConfig(config.strict, config.rules, config.customRules);
        /**
         * and go!
         */
        var _c = execute_1.default(rules, scripts, consoleReporter_1.warning, config.fix), issues = _c[0], fixedScripts = _c[1], issuesFixed = _c[2];
        if (config.fix && issuesFixed > 0) {
            writePackageScripts(fixedScripts);
            consoleReporter_1.success("Fixed " + issuesFixed + " issue" + (issuesFixed > 1 ? "s" : "") + "!");
        }
        if (issues.length - issuesFixed === 0) {
            consoleReporter_1.success("✨  All good");
            consoleReporter_1.dump(config.json);
            processExit(constants_1.PROCESS_EXIT_OK);
        }
        consoleReporter_1.dump(config.json);
        processExit(constants_1.PROCESS_EXIT_ERROR);
    }
    catch (err) {
        consoleReporter_1.error(err);
    }
});
