"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.error = exports.dump = exports.success = exports.warning = void 0;
var chalk_1 = __importDefault(require("chalk"));
var utils_1 = require("./utils");
var PREFIX = "⧙։⧘";
var stashed = [];
var stash = function (message, type) {
    stashed.push({
        message: message,
        type: type,
    });
};
var warning = function (template, values) {
    var message = utils_1.makeMessage(template, values);
    stash(message, "warning");
};
exports.warning = warning;
var success = function (template, values) {
    var message = utils_1.makeMessage(template, values);
    stash(message, "success");
};
exports.success = success;
var dump = function (jsonOutput) {
    var problemCount = stashed.length;
    if (jsonOutput) {
        // eslint-disable-next-line no-console
        console.log(JSON.stringify(stashed, null, "\t"));
    }
    else {
        stashed.forEach(function (_a) {
            var message = _a.message, type = _a.type;
            print(type, message);
        });
    }
    stashed = [];
    return problemCount;
};
exports.dump = dump;
var error = function (message) {
    print("error", message);
};
exports.error = error;
var print = function (type, message) {
    switch (type) {
        case "error": {
            // eslint-disable-next-line no-console
            console.log(chalk_1.default.bold.red(PREFIX + " [error] " + message));
            break;
        }
        case "warning": {
            var notUnderlined = chalk_1.default.yellow.bold(PREFIX + " [" + type + "]");
            var underlined = chalk_1.default.yellow.underline(message);
            // eslint-disable-next-line no-console
            console.log(notUnderlined + " " + underlined);
            break;
        }
        case "success": {
            // eslint-disable-next-line no-console
            console.log(chalk_1.default.bold.gray(PREFIX + " [\u2714\uFE0F] " + message));
            break;
        }
    }
};
