"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var utils_1 = require("./utils");
var errors_1 = require("./errors");
var execute = function (rules, scripts, warning, configFix) {
    /**
     * keep track of everything
     */
    if (configFix === void 0) { configFix = false; }
    var issues = [];
    var issuesFixed = 0;
    var patchScripts = function (newScripts) {
        issuesFixed++;
        scripts = newScripts;
    };
    /**
     * execution functions
     */
    var executeObjectRule = function (_a) {
        var validate = _a.validate, message = _a.message, name = _a.name, fix = _a.fix;
        if (typeof validate !== "function") {
            throw new errors_1.ValidationFunctionInvalidError("Rule validation function is not a function (" + name + ")");
        }
        var validationResult = validate(scripts);
        var fixable = typeof fix === "function";
        /**
         * validate
         */
        var valid = typeof validationResult === "boolean"
            ? validationResult
            : validationResult.length < 1;
        if (valid) {
            return;
        }
        /**
         * warn of invalidity
         */
        var warningMessage = typeof validationResult === "boolean"
            ? message + " (" + name + ")"
            : utils_1.makeMessage(message + " (" + name + ")", {
                names: validationResult.join(", "),
            });
        /**
         * potentially fix
         */
        if (configFix && fixable && fix) {
            patchScripts(fix(scripts));
            return;
        }
        /**
         * keep track of everything
         */
        issues.push({
            name: name,
            affected: undefined,
            type: "warning",
            message: warningMessage,
        });
        if (typeof warning === "function") {
            warning(warningMessage, validationResult);
        }
    };
    var executeEntryRule = function (_a) {
        var validate = _a.validate, message = _a.message, name = _a.name, fix = _a.fix;
        if (typeof validate !== "function") {
            throw new errors_1.ValidationFunctionInvalidError(name);
        }
        var fixable = typeof fix === "function";
        var pairs = Object.entries(scripts);
        /**
         * iterate all the scripts
         */
        pairs.forEach(function (_a) {
            var key = _a[0], value = _a[1];
            var valid = validate(key, value, scripts);
            if (valid) {
                return;
            }
            var warningMessage = utils_1.makeMessage(message + " (" + name + ")", {
                name: key,
            });
            /**
             * potentially fix
             */
            if (configFix && fixable && fix) {
                var _b = fix(key, value), toKey = _b[0], fixedValue = _b[1];
                var fixedScripts = utils_1.patchScriptObjectEntry(scripts, key, toKey, fixedValue);
                patchScripts(fixedScripts);
                return;
            }
            /**
             * keep track of everything
             */
            issues.push({
                name: name,
                affected: key,
                type: "warning",
                message: warningMessage,
            });
            if (typeof warning === "function") {
                warning(warningMessage, key);
            }
        });
    };
    /**
     * and go!
     */
    rules.forEach(function (rule) {
        if (rule.isObjectRule) {
            executeObjectRule(rule);
        }
        else {
            executeEntryRule(rule);
        }
    });
    return [issues, scripts, issuesFixed];
};
exports.default = execute;
