#!/usr/bin/env node
"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
// eslint-disable-next-line node/shebang
var userPackageScripts_1 = __importDefault(require("./userPackageScripts"));
var loadRules_1 = require("./loadRules");
var errors_1 = require("./errors");
var execute_1 = __importDefault(require("./execute"));
var constants_1 = require("./constants");
var utils_1 = require("./utils");
exports.default = (function (moduleConfig) {
    /**
     * validate config
     */
    var _a, _b;
    if (moduleConfig.packageFile && moduleConfig.packageScripts) {
        throw new errors_1.ConfigError("Either specify a package.json location or a scripts object but not both" +
            JSON.stringify(moduleConfig));
    }
    if (!moduleConfig.packageFile && !moduleConfig.packageScripts) {
        throw new errors_1.ConfigError("You have to specify a package.json location or a scripts object");
    }
    var config = __assign(__assign({}, constants_1.DEFAULT_CONFIG), moduleConfig);
    /**
     * find scripts
     */
    var scripts = (_a = moduleConfig.packageScripts) !== null && _a !== void 0 ? _a : {};
    if (!moduleConfig.packageScripts && moduleConfig.packageFile) {
        var readPackageScripts = userPackageScripts_1.default(utils_1.makePackageFilePath((_b = config.packageFile) !== null && _b !== void 0 ? _b : "")).readPackageScripts;
        scripts = readPackageScripts(config.ignoreScripts);
    }
    /**
     * ok go!
     */
    var rules = loadRules_1.loadRulesFromRuleConfig(config.strict, config.rules, config.customRules);
    var _c = execute_1.default(rules, scripts, function () { }, config.fix), issues = _c[0], fixedScripts = _c[1];
    return {
        issues: issues,
        scripts: config.fix ? fixedScripts : scripts,
    };
});
