"use strict";
var __spreadArray = (this && this.__spreadArray) || function (to, from) {
    for (var i = 0, il = from.length, j = to.length; i < il; i++, j++)
        to[j] = from[i];
    return to;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.patchScriptObjectEntry = exports.makeMessage = exports.filterPackageScriptsByKeys = exports.slugify = exports.makePackageFilePath = void 0;
var fs_1 = __importDefault(require("fs"));
var path_1 = __importDefault(require("path"));
var errors_1 = require("./errors");
var makePackageFilePath = function (packageFile) {
    // resolve package.json path
    packageFile = packageFile.endsWith("/package.json")
        ? packageFile
        : packageFile + "/package.json";
    packageFile = path_1.default.resolve(packageFile);
    // does it exist?
    if (!fs_1.default.existsSync(packageFile)) {
        throw new errors_1.PackageFileNotFoundError(packageFile);
    }
    return packageFile;
};
exports.makePackageFilePath = makePackageFilePath;
var slugify = function (str) {
    return str
        .trim()
        .toLowerCase()
        .replace(/[^A-Za-z-]/g, "-")
        .replace(/^-/g, "")
        .replace(/-+/g, "-")
        .replace(/-$/g, "");
};
exports.slugify = slugify;
var filterPackageScriptsByKeys = function (raw, removes) {
    return Object.keys(raw)
        .filter(function (k) { return !removes.includes(k); })
        .reduce(function (obj, key) {
        obj[key] = raw[key];
        return obj;
    }, {});
};
exports.filterPackageScriptsByKeys = filterPackageScriptsByKeys;
var makeMessage = function (template, values) {
    var message = template;
    if (values !== undefined) {
        var pairs = Object.entries(values);
        pairs.forEach(function (_a) {
            var key = _a[0], value = _a[1];
            message = message.replace("{{" + key + "}}", value);
        });
    }
    return message;
};
exports.makeMessage = makeMessage;
var fromEntries = function (iterable) {
    return __spreadArray([], iterable).reduce(function (obj, _a) {
        var key = _a[0], val = _a[1];
        obj[key] = val;
        return obj;
    }, {});
};
var patchScriptObjectEntry = function (scripts, fromKey, toKey, value) {
    return fromEntries(Object.entries(scripts).map(function (_a) {
        var k = _a[0], v = _a[1];
        return k === fromKey ? [toKey, value] : [k, v];
    }));
};
exports.patchScriptObjectEntry = patchScriptObjectEntry;
